Changelog
=========

v1.0.2
------

Fix bug when collecting versions.
Reference: https://github.com/nexB/purldb/issues/486


v1.0.1
------

Add missing key data files.


v1.0.0
------

Initial release.
